﻿using Microsoft.AspNetCore.Mvc;

namespace Hotline.Api.Middleware;

/// <summary>
/// 为特定的返回结果添加 头部信息 的中间件
/// </summary>
public class HeaderMiddleware
{
    private readonly RequestDelegate _next;

    public HeaderMiddleware(RequestDelegate next)
    {
        _next = next;
    }

    public async Task InvokeAsync(HttpContext context)
    {
        await _next(context);

        // 为返回类型是 FileStreamResult 的请求添加 头部信息
        if (context.Response.StatusCode == StatusCodes.Status200OK)
        {
            var result = context.Items["Result"] as IActionResult;

            if (result is FileStreamResult)
            {
                context.Response.Headers.Add("Access-Control-Expose-Headers", "Content-Disposition");
            }
        }
    }
}
